"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var MessageIDGenerator_1 = require("./MessageIDGenerator");
var Messenger_1 = require("./Messenger");
var rxjs_1 = require("./vendor/rxjs");
var MessageFactory_1 = require("./MessageFactory");
var MessageValidator_1 = require("./MessageValidator");
var PostmessageAdapter_1 = require("./PostmessageAdapter");
// -------------------------------------------------------------------------------------
// Private data / exports for internal wiring
// -------------------------------------------------------------------------------------
/**
 * The observable implementation to use for creating the event streams of new messengers.
 */
var _Observable = rxjs_1.Observable;
/**
 * returns the active Rx.Observable implementation. Used by the messenger class to
 * obtain an Observable constructor reference at runtime.
 */
function getObservable() {
    return _Observable;
}
exports.getObservable = getObservable;
// -------------------------------------------------------------------------------------
// API implementation
// -------------------------------------------------------------------------------------
/**
 * Sets given Rx.Observable implementation as the active implementation for new messengers.
 * Any messenger created hereafter will use this implementation.
 */
function useObservable(newImplementation) {
    _Observable = newImplementation;
}
exports.useObservable = useObservable;
function connect(remoteWindow, remoteOrigin) {
    if (window === remoteWindow) {
        throw new Error('Remote window can not be the same as the local window environment');
    }
    return new Messenger_1.Messenger(new MessageFactory_1.MessageFactory(new MessageIDGenerator_1.MessageIDGenerator()), new MessageValidator_1.MessageValidator(remoteWindow, remoteOrigin), new PostmessageAdapter_1.PostmessageAdapter(remoteWindow, remoteOrigin));
}
exports.connect = connect;
// ---------------------------------------------------------------------------------------
// API Exports
// ---------------------------------------------------------------------------------------
// noinspection JSUnusedGlobalSymbols
var defaultNamespace = { connect: connect, useObservable: useObservable, getObservable: getObservable };
exports.default = defaultNamespace;
//# sourceMappingURL=index.js.map