import { MessageIDGenerator } from './MessageIDGenerator';
import { Messenger } from './Messenger';
import { Observable } from './vendor/rxjs';
import { MessageFactory } from './MessageFactory';
import { MessageValidator } from './MessageValidator';
import { PostmessageAdapter } from './PostmessageAdapter';
// -------------------------------------------------------------------------------------
// Private data / exports for internal wiring
// -------------------------------------------------------------------------------------
/**
 * The observable implementation to use for creating the event streams of new messengers.
 */
var _Observable = Observable;
/**
 * returns the active Rx.Observable implementation. Used by the messenger class to
 * obtain an Observable constructor reference at runtime.
 */
export function getObservable() {
    return _Observable;
}
// -------------------------------------------------------------------------------------
// API implementation
// -------------------------------------------------------------------------------------
/**
 * Sets given Rx.Observable implementation as the active implementation for new messengers.
 * Any messenger created hereafter will use this implementation.
 */
export function useObservable(newImplementation) {
    _Observable = newImplementation;
}
export function connect(remoteWindow, remoteOrigin) {
    if (window === remoteWindow) {
        throw new Error('Remote window can not be the same as the local window environment');
    }
    return new Messenger(new MessageFactory(new MessageIDGenerator()), new MessageValidator(remoteWindow, remoteOrigin), new PostmessageAdapter(remoteWindow, remoteOrigin));
}
// ---------------------------------------------------------------------------------------
// API Exports
// ---------------------------------------------------------------------------------------
// noinspection JSUnusedGlobalSymbols
var defaultNamespace = { connect: connect, useObservable: useObservable, getObservable: getObservable };
export default defaultNamespace;
//# sourceMappingURL=index.js.map