/**
 * The IMessageObject interface defines the format for data property values of MessageEvent objects.
 * This interface describes the actual format of data sent with postMessage that is required for
 * another RxPostmessenger on the other end of the line to be able to correctly interpret the
 * message.
 */
export interface IMessageObject<T = any> {
    readonly id: string;
    readonly type: MessageType;
    readonly channel: string;
    readonly payload: T;
}
export interface IRequestObject<T = any> extends IMessageObject<T> {
    readonly type: 'request';
}
export interface IResponseObject<T = any> extends IMessageObject<T> {
    readonly requestId: string;
    readonly type: 'response';
}
export interface INotificationObject<T = any> extends IMessageObject<T> {
    readonly type: 'notification';
}
export declare type AnyMessage = IRequestObject | IResponseObject | INotificationObject;
export interface IMessageTypeMap<T = any> {
    request: IRequestObject;
    response: IResponseObject;
    notification: INotificationObject;
}
export declare type MessageType = keyof IMessageTypeMap;
export declare type MappedMessage<T extends MessageType> = IMessageTypeMap[T];
